Because of the sensitivity of the Ljung-Box test to the number of lags involved in the test, this function computes
lower bound of this test and draws it's plot.
Usage
Q_H(simnum = 10000, TT = 50)
Value
Lower bound of the Ljung-Box test and it's plot.
Arguments
simnum
number of simulation iterations.
TT
length of time serie.
Author
Hossein hassani, Masoud yarmohammdi, Mohammad reza yeganegi and Leila Marvian Mashhad.
References
Hassani, H., & Yeganegi, M. R. (2019). "Sum of squared ACF and the Ljung-Box statistics."
Physica A: Statistical Mechanics and Its Applications, 520, 81-86.